Crate prikk_object

Crate prikk_object 

Object identity and canonical payload definitions for Prikk.

This crate deliberately does not use protobuf bytes for object identity. It implements a small deterministic canonical encoder seed that can be extended as FDD-03 matures.

Re-exports

pub use canonical::CanonicalEncode;
pub use canonical::CanonicalWriter;
pub use canonical::WireType;
pub use envelope::ObjectEnvelope;
pub use id::OBJECT_ID_DOMAIN;
pub use id::ObjectId;
pub use id::ObjectType;
pub use signature::Signature;
pub use signature::SignatureAlgorithm;
pub use signature::SignerRole;
pub use payload::*;

Modules

canonical
Deterministic canonical encoding helpers.
envelope
Object envelope.
id
Object identifiers and object type codes.
payload
Canonical payload shapes for Prikk object types.
signature
Signature metadata and signed-byte construction.