ObjectEnvelope

Struct ObjectEnvelope 

pub struct ObjectEnvelope {
    pub object_type: ObjectType,
    pub schema_version: u32,
    pub canonical_payload: Vec<u8>,
    pub signatures: Vec<Signature>,
}
Object envelope containing unsigned canonical payload bytes plus external signatures.

Fields

object_type: ObjectType

Object type.

schema_version: u32

Schema version.

canonical_payload: Vec<u8>

Unsigned canonical payload bytes.

signatures: Vec<Signature>

Signatures over the object ID. Signatures are not part of the object ID preimage.

Implementations

Source

impl ObjectEnvelope

pub fn unsigned( object_type: ObjectType, schema_version: u32, canonical_payload: Vec<u8>, ) -> Self

Construct a new unsigned envelope.

pub fn object_id(&self) -> ObjectId

Compute this envelope’s object ID from its unsigned payload.

pub fn validate(&self) -> Result<()>

Validate envelope metadata and signatures structurally.

pub fn add_signature(&mut self, signature: Signature) -> Result<()>

Append a signature. This does not recompute or change the object ID.