pub struct ObjectEnvelope {
pub object_type: ObjectType,
pub schema_version: u32,
pub canonical_payload: Vec<u8>,
pub signatures: Vec<Signature>,
}Expand description
Object envelope containing unsigned canonical payload bytes plus external signatures.
Fields
object_type: ObjectTypeObject type.
schema_version: u32Schema version.
canonical_payload: Vec<u8>Unsigned canonical payload bytes.
signatures: Vec<Signature>Signatures over the object ID. Signatures are not part of the object ID preimage.
Implementations
Sourceimpl ObjectEnvelope
impl ObjectEnvelope
Sourcepub fn unsigned(
object_type: ObjectType,
schema_version: u32,
canonical_payload: Vec<u8>,
) -> Self
pub fn unsigned( object_type: ObjectType, schema_version: u32, canonical_payload: Vec<u8>, ) -> Self
Construct a new unsigned envelope.
Sourcepub fn object_id(&self) -> ObjectId
pub fn object_id(&self) -> ObjectId
Compute this envelope’s object ID from its unsigned payload.
Sourcepub fn add_signature(&mut self, signature: Signature) -> Result<()>
pub fn add_signature(&mut self, signature: Signature) -> Result<()>
Append a signature. This does not recompute or change the object ID.